@@ -47,6 +47,10 @@
 #' @param check_version if \code{TRUE}, check that the new version is greater
 #'   than the current version on CRAN, by setting the
 #'   \code{_R_CHECK_CRAN_INCOMING_} environment variable to \code{TRUE}.
+#'   (This also enables spell checking of the package's \code{DESCRIPTION}
+#'   by setting the \code{_R_CHECK_CRAN_INCOMING_USE_ASPELL_} environment
+#'   variable to \code{TRUE}; if no spell checker is installed, a warning is
+#'   issued.)
 #' @param force_suggests if \code{FALSE}, don't force suggested packages, by
 #'   setting the \code{_R_CHECK_FORCE_SUGGESTS_} environment variable to
 #'   \code{FALSE}.
@@ -111,7 +115,7 @@ check_r_cmd <- function(built_path = NULL, cran = TRUE, check_version = FALSE,
   # not set, R CMD check will use the defaults as described in R Internals.
   env_vars <- c(
     if (cran) cran_env_vars(),
-    if (check_version) c("_R_CHECK_CRAN_INCOMING_" = "TRUE"),
+    if (check_version) c("_R_CHECK_CRAN_INCOMING_" = "TRUE", aspell_env_var()),
     if (!force_suggests) c("_R_CHECK_FORCE_SUGGESTS_" = "FALSE")
   )
 
@@ -150,6 +154,8 @@ cran_env_vars <- function() {
     "_R_CHECK_REPLACING_IMPORTS_"        = "TRUE",
     "_R_CHECK_SCREEN_DEVICE_"            = "stop",
     "_R_CHECK_TOPLEVEL_FILES_"           = "TRUE",
+    "_R_CHECK_S3_METHODS_NOT_REGISTERED_"= "TRUE",
+    "_R_CHECK_OVERWRITE_REGISTERED_S3_METHODS_" = "TRUE",
     # The following are used for CRAN incoming checks according to the R
     # internals doc, but they're not in the list at the bottom of the Tools
     # section (have to look at the description of the individual env vars).
@@ -157,3 +163,16 @@ cran_env_vars <- function() {
     "_R_CHECK_LIMIT_CORES_"              = "TRUE"
   )
 }
+
+aspell_env_var <- function() {
+  tryCatch(
+    {
+      utils::aspell(NULL)
+      c("_R_CHECK_CRAN_INCOMING_USE_ASPELL_" = "TRUE")
+    },
+    error = function(e) {
+      warning("Skipping spell check: ", e$message, call. = FALSE)
+      NULL
+    }
+  )
+}
