@@ -1,7 +1,7 @@
 #' Use roxygen to document a package.
 #'
 #' This function is a wrapper for the \code{\link[roxygen2]{roxygenize}()}
-#' from the roxygen2 package. See the documentation and vignettes of
+#' function from the roxygen2 package. See the documentation and vignettes of
 #' that package to learn how to use roxygen.
 #'
 #' @param pkg package description, can be path or package name.  See
@@ -16,9 +16,6 @@ document <- function(pkg = ".", clean = NULL, roclets = NULL, reload = TRUE) {
     warning("Clean argument deprecated: roxygen2 now automatically cleans up",
       call. = FALSE)
   }
-  if (!is_installed("roxygen2", 4)) {
-    stop("Please install latest roxygen2", call. = FALSE)
-  }
 
   pkg <- as.package(pkg)
   message("Updating ", pkg$package, " documentation")
