@@ -21,6 +21,13 @@
 #' @param host Github API host to use. Override with your github enterprise
 #'   hostname, for example, \code{"github.hostname.com/api/v3"}.
 #' @param ... Other arguments passed on to \code{\link{install}}.
+#' @details
+#' Attempting to install from a source repository that uses submodules
+#' raises a warning. Because the zipped sources provided by GitHub do not
+#' include submodules, this may lead to unexpected behaviour or compilation
+#' failure in source packages. In this case, cloning the repository manually
+#' using \code{\link{install_git}} with \code{args="--recursive"} may yield
+#' better results.
 #' @export
 #' @family package installation
 #' @seealso \code{\link{github_pull}}
@@ -86,8 +93,8 @@ remote_download.github_remote <- function(x, quiet = FALSE) {
   }
 
   dest <- tempfile(fileext = paste0(".zip"))
-  src <- paste0("https://", x$host, "/repos/", x$username, "/", x$repo,
-    "/zipball/", x$ref)
+  src_root <- paste0("https://", x$host, "/repos/", x$username, "/", x$repo)
+  src <- paste0(src_root, "/zipball/", x$ref)
 
   if (!is.null(x$auth_token)) {
     auth <- httr::authenticate(
@@ -99,9 +106,20 @@ remote_download.github_remote <- function(x, quiet = FALSE) {
     auth <- NULL
   }
 
+  if (github_has_remotes(x, auth))
+    warning("Github repo contains submodules, may not function as expected!",
+      call. = FALSE)
+
   download(dest, src, auth)
 }
 
+github_has_remotes <- function(x, auth = NULL) {
+  src_root <- paste0("https://", x$host, "/repos/", x$username, "/", x$repo)
+  src_submodules <- paste0(src_root, "/contents/.gitmodules?ref=", x$ref)
+  response <- httr::HEAD(src_submodules, , auth)
+  identical(httr::status_code(response), 200L)
+}
+
 #' @export
 remote_metadata.github_remote <- function(x, bundle = NULL, source = NULL) {
   # Determine sha as efficiently as possible
@@ -200,7 +218,7 @@ parse_git_repo <- function(path) {
     username_rx, repo_rx, subdir_rx, ref_or_pull_or_release_rx)
 
   param_names <- c("username", "repo", "subdir", "ref", "pull", "release", "invalid")
-  replace <- setNames(sprintf("\\%d", seq_along(param_names)), param_names)
+  replace <- stats::setNames(sprintf("\\%d", seq_along(param_names)), param_names)
   params <- lapply(replace, function(r) gsub(github_rx, r, path, perl = TRUE))
   if (params$invalid != "")
     stop(sprintf("Invalid git repo: %s", path))
