@@ -43,6 +43,9 @@
 #' @param threads number of concurrent threads to use for installing
 #'   dependencies.
 #'   It defaults to the option \code{"Ncpus"} or \code{1} if unset.
+#' @param ... additional arguments passed to \code{\link{install.packages}}
+#'   when installing dependencies. \code{pkg} is installed with
+#'   \code{R CMD INSTALL}.
 #' @export
 #' @family package installation
 #' @seealso \code{\link{with_debug}} to install packages with debugging flags
@@ -51,7 +54,8 @@ install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
                     args = getOption("devtools.install.args"), quiet = FALSE,
                     dependencies = NA, build_vignettes = FALSE,
                     keep_source = getOption("keep.source.pkgs"),
-                    threads = getOption("Ncpus", 1)) {
+                    threads = getOption("Ncpus", 1),
+                    ...) {
 
   pkg <- as.package(pkg)
   check_build_tools(pkg)
@@ -62,10 +66,10 @@ install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
   if (build_vignettes && missing(dependencies)) {
     dependencies <- TRUE
   }
-  install_deps(pkg, dependencies = dependencies, threads = threads)
+  install_deps(pkg, dependencies = dependencies, threads = threads, ...)
 
   # Build the package. Only build locally if it doesn't have vignettes
-  has_vignettes <- length(tools::pkgVignettes(dir = pkg$path)$doc > 0)
+  has_vignettes <- length(tools::pkgVignettes(dir = pkg$path)$docs > 0)
   if (local && !(has_vignettes && build_vignettes)) {
     built_path <- pkg$path
   } else {
@@ -91,47 +95,16 @@ install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
   invisible(TRUE)
 }
 
-#' Install package dependencies
+#' Install package dependencies if needed.
 #'
 #' @inheritParams install
+#' @param ... additional arguments passed to \code{\link{install.packages}}.
 #' @export
 #' @examples
 #' \dontrun{install_deps(".")}
 install_deps <- function(pkg = ".", dependencies = NA,
-                         threads = getOption("Ncpus", 1)) {
-  pkg <- as.package(pkg)
-  info <- pkg_deps(pkg, dependencies)
-
-  # Packages that are not already installed or without required versions
-  needs_install <- function(pkg, compare, version) {
-    if (length(find.package(pkg, quiet = TRUE)) == 0) return(TRUE)
-    if (is.na(compare)) return(FALSE)
-
-    compare <- match.fun(compare)
-    !compare(packageVersion(pkg), version)
-  }
-  needed <- Map(needs_install, info$name, info$compare, info$version)
-  deps <- info$name[as.logical(needed)]
-  if (length(deps) == 0) return(invisible())
-
-  message("Installing dependencies for ", pkg$package, ":\n",
-    paste(deps, collapse = ", "))
-  utils::install.packages(deps, dependencies = NA, Ncpus = threads)
-  invisible(deps)
-}
-
-pkg_deps <- function(pkg = ".", dependencies = NA) {
-  pkg <- as.package(pkg)
-
-  deps <- if (identical(dependencies, NA)) {
-    c("Depends", "Imports", "LinkingTo")
-  } else if (isTRUE(dependencies)) {
-    c("Depends", "Imports", "LinkingTo", "Suggests", "VignetteBuilder")
-  } else if (identical(dependencies, FALSE)) {
-    character(0)
-  } else dependencies
-
-  deps <- unlist(pkg[tolower(deps)], use.names = FALSE)
-
-  parse_deps(paste(deps, collapse = ','))
+                         threads = getOption("Ncpus", 1),
+                         ...) {
+  pkg <- dev_package_deps(pkg, dependencies = dependencies)
+  update(pkg, Ncpus = threads, ...)
 }
