@@ -246,8 +246,18 @@ version_info <- list(
   ),
   "3.1" = list(
     version_min = "3.0.0",
+    version_max = "3.1.99",
+    path = c("bin", "gcc-4.6.3/bin")
+  ),
+  "3.2" = list(
+    version_min = "3.1.0",
     version_max = "3.2.99",
     path = c("bin", "gcc-4.6.3/bin")
+  ),
+  "3.3" = list(
+    version_min = "3.2.0",
+    version_max = "3.3.99",
+    path = c("bin", "gcc-4.6.3/bin")
   )
 )
 
